==> puppet-tripleo-6.5.10.tar.gz: openstack-tripleo-6.5.10/spec/classes/tripleo_profile_base_cinder_backup_swift_spec.rb <==
#
# Copyright (C) 2016 Red Hat, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
#

require 'spec_helper'

describe 'tripleo::profile::base::cinder::backup::swift' do
  shared_examples_for 'tripleo::profile::base::cinder::backup::swift' do
    let(:pre_condition) do
      <<-EOF
      class { '::tripleo::profile::base::cinder': step => #{params[:step]}, rabbit_hosts => ['127.0.0.1'] }
      class { '::tripleo::profile::base::cinder::backup': step => #{params[:step]} }
      EOF
    end

    context 'with step less than 4' do
      let(:params) { { :step => 3 } }

      it 'should do nothing' do
        is_expected.to contain_class('tripleo::profile::base::cinder::backup::swift')
        is_expected.to contain_class('tripleo::profile::base::cinder::backup')
        is_expected.to_not contain_class('cinder::backup::swift')
      end
    end

    context 'with step 4' do
      let(:params) { {
        :step => 4,
      } }

      it 'should trigger complete configuration' do
        is_expected.to contain_class('cinder::backup::swift')
      end
    end
  end


  on_supported_os.each do |os, facts|
    context "on #{os}" do
      let(:facts) do
        facts.merge({ :hostname => 'node.example.com' })
      end

      it_behaves_like 'tripleo::profile::base::cinder::backup::swift'
    end
  end
end

==> puppet-tripleo-7.4.7.tar.gz: openstack-tripleo-7.4.7/spec/classes/tripleo_profile_base_cinder_backup_swift_spec.rb <==
#
# Copyright (C) 2016 Red Hat, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
#

require 'spec_helper'

describe 'tripleo::profile::base::cinder::backup::swift' do
  shared_examples_for 'tripleo::profile::base::cinder::backup::swift' do
    let(:pre_condition) do
      <<-EOF
      class { '::tripleo::profile::base::cinder': step => #{params[:step]}, oslomsg_rpc_hosts => ['127.0.0.1'] }
      class { '::tripleo::profile::base::cinder::backup': step => #{params[:step]} }
      EOF
    end

    context 'with step less than 4' do
      let(:params) { { :step => 3 } }

      it 'should do nothing' do
        is_expected.to contain_class('tripleo::profile::base::cinder::backup::swift')
        is_expected.to contain_class('tripleo::profile::base::cinder::backup')
        is_expected.to_not contain_class('cinder::backup::swift')
      end
    end

    context 'with step 4' do
      let(:params) { {
        :step => 4,
      } }

      it 'should trigger complete configuration' do
        is_expected.to contain_class('cinder::backup::swift')
      end
    end
  end


  on_supported_os.each do |os, facts|
    context "on #{os}" do
      let(:facts) do
        facts.merge({ :hostname => 'node.example.com' })
      end

      it_behaves_like 'tripleo::profile::base::cinder::backup::swift'
    end
  end
end
